# -*- coding: utf-8 -*-

import pymysql.cursors

class Rds():
    def __init__(self, db_host ,db_user ,db_password ,db_name ,charset, debug=False):
        self.db_host = db_host
        self.db_user = db_user
        self.db_password = db_password
        self.db_name = db_name
        self.charset = charset

        # デバッグモード
        self.debug = debug

    # connectionを返す
    def _dbConnection(self):
        if self.debug:
            print('db connection')

        connection = pymysql.connect(
            host=self.db_host,
            user=self.db_user,
            password=self.db_password,
            db=self.db_name,
            charset=self.charset,
            # cursorclassを指定することで
            # Select結果をtupleではなくdictionaryで受け取れ��?
            cursorclass=pymysql.cursors.DictCursor)
        return connection

    # db切断
    def _dbClosed(self):
        if self.debug:
            print('db closed')
        self.connection.close()

    # sql実行
    # def exexSql(self, sql):
    #     cursor.execute(sql)


    # インサートの実行
    def insertExecute(self, table_name, cols_name, values):
        # sql文の作成
        sql = "INSERT INTO " + table_name + " (" + cols_name + " ) VALUES ( " + values + " )"

        if self.debug:
            print(sql)

        # # sql文の実行
        self.connection = self._dbConnection()
        with self.connection.cursor() as cursor:
            r = cursor.execute(sql)

            # autocommitではないので、明示的にコミットする
            self.connection.commit()

        self._dbClosed()
        return r

    # リストによるインサートの実行
    def insertListExecute(self, table_name ,data_list_array):

        for data_list in data_list_array:

            cols = data_list.keys()
            values = data_list.values()

            cols_name, values_name = '', ''

            for col in cols:
                cols_name += col + ','
            else:
                cols_name = cols_name[:-1]

            for value in values:
                values_name += str(value) + ','
            else:
                values_name = values_name[:-1]

            # sql文の作成
            sql = "INSERT INTO " + table_name + " (" + cols_name + " ) VALUES ( " + values_name + " )"

            if self.debug:
                print(sql)

            # sql文の実行
            self.connection = self._dbConnection()
            with self.connection.cursor() as cursor:
                r = cursor.execute(sql)

                # autocommitではないので、明示的にコミットする
                self.connection.commit()

        self._dbClosed()
        return r



    # select文実行
    def selectExecute(self, table_name, cols_name, where=''):
        # sql文の作成
        sql = "SELECT " + cols_name + " FROM " + table_name
        if where :
            sql = sql + " wHERE "+where

        if self.debug:
            print(sql)

        # SQLを実行する
        self.connection = self._dbConnection()
        with self.connection.cursor() as cursor:
            cursor.execute(sql)

            # Select結果を取り出す
            results = cursor.fetchall()

        self._dbClosed()
        return results

    # update文実行
    def updateExecute(self, table_name, col_value, where=''):
        # sql文の作成
        sql = "UPDATE " + table_name + " SET " + col_value
        if where :
            sql += " WHERE " + where

        if self.debug:
            print(sql)

        # # sql文の実行
        self.connection = self._dbConnection()
        with self.connection.cursor() as cursor:
            r = cursor.execute(sql)

            # autocommitではないので、明示的にコミットする
            self.connection.commit()

        self._dbClosed()
        return r


    # update文実行
    def updateListExecute(self, table_name, data_list_array, where_word='where'):
        count = 0
        for j in range(0, len(data_list_array)):
            # data_list_arrayにwhereがあればwhereを削除してwhereに代入
            where = ''
            if where_word in ata_list_array[j]:
                where = data_list_array.pop(where_word)

            cols = data_list_array[j].keys()
            values = data_list_array[j].values()

            col_value=''
            for i in range(0, len(cols)):
                col_value += cols[i]+'='+str(values[i])+','
            col_value = col_value[:-1]

            # sql文の作成
            sql = "UPDATE " + table_name + " SET " + col_value
            if where:
                sql += " WHERE " + where

            if self.debug:
                print(sql)

            # # sql文の実行
            self.connection = self._dbConnection()
            with self.connection.cursor() as cursor:
                r = cursor.execute(sql)

                # autocommitではないので、明示的にコミットする
                self.connection.commit()

            count += 1

        self._dbClosed()
        return r


    # delete文の実行
    def deleteExecute(self, table_name, where=''):
        sql = "DELETE FROM " + table_name
        if where :
            sql += " wHERE " + where

        if self.debug:
            print(sql)








        pass










#



# -*- coding: utf-8 -*-

from boto.s3.connection import S3Connection
from boto.s3.key import Key


# S3Connection('アクセスキーの文字列', 'シークレットアクセスキーの文字列')
conn = S3Connection(
            'AKIAIUWJ5KW3QBKLMW3A',
            'alg9nIlBliiEvma6HDO/Wie96w73/gTHwsxK1NZ9')

bucket = conn.get_bucket('campbel2525')

# コンテンツを列挙する
# print list(bucket)
# print bucket.get_all_keys()

# フォルダのファイル一覧
for key in bucket.list(prefix='sotuken/results/tokyo_1/01_01'):
    print(key.name, key.size, key.last_modified)

# コンテンツを削除する
k = bucket.get_key('sotuken/results/tokyo_1/01_01')
k.delete()
# 空のディレクトリ作成
# k = Key(bucket)
# for month in range(1, 13):
#     for mode in ['01', '02', '03']:
#         print '{0:02d}'.format(month)+'_'+mode
#
#         k.key = 'sotuken/results/tokyo_1/'+'{0:02d}'.format(month)+'_'+mode+'/'
#         k.set_contents_from_string('')

# ファイツの保存
# f = Key(bucket)
# # 保存するファイル名。s3側
# f.key = 'test_folder/test1.mp4'
# # 保存するもの。自分側のファイル
# f.set_contents_from_filename('test3.txt')


# # ファイツの保存
# f = Key(bucket)
# # 保存するファイル名。s3側
# f.key = 'sotuken/results/tokyo_1/01_01/'
# # 保存するもの。自分側のファイル
# fout = open('/Volumes/microSd/downloads/', 'w')
# f.get_file(fout)








#



# -*- coding: utf-8 -*-
from boto.s3.connection import S3Connection
from boto.s3.key import Key
import os
class S3():

    def __init__(self, access_key, secret_access_key, bucket_name):
        # self.access_key = access_key
        # self.secret_access_key = secret_access_key

        # S3Connection('アクセスキーの文字列', 'シークレットアクセスキーの文字列')
        conn = S3Connection(access_key,secret_access_key)
        self.bucket = conn.get_bucket(bucket_name)

    # コンテンツを削除する
    def deleteFile(self, key_name):
        k = self.bucket.get_key(key_name)
        k.delete()

    # s3に空のディレクトリ作成
    def createDir(self, dir_name):
        k = Key(bucket)
        k.key = dir_name
        k.set_contents_from_string('')

    # コンテンツを列挙する
    def getBucketList(self):
        return list(bucket)

    # コンテンツを列挙する
    def getDirList(self, dir_name):
        return list(dir_name)

    # バケットを返す。何かに使いたい時のため。
    def getBucket(self):
        return self.bucket

    def getKeyNameList(self, prefix):
        key_name = []
        for key in self.bucket.list(prefix=prefix):
            key_name.append(key.name)
        return key_name

    # ファイルのアップロード
    def uploadFileToS3(self, local_file, s3_file):
        # ファイツの保存
        f = Key(self.bucket)
        # 保存するファイル名。s3側
        f.key = s3_file
        # 保存するもの。自分側のファイル
        f.set_contents_from_filename(local_file)

    # local内のフォルダン中のファイル全部アップロード
    def uploadFilesToS3(self, local_dir, s3_dir):
        files = os.listdir(local_dir)

        for file_name in files:
            if os.path.isfile(local_dir+file_name):
                # print local_dir+file_name
                self.uploadFileToS3(local_dir+file_name, s3_dir+file_name)

    # 1つのファイルをダウンロード
    # key_name:campbel2525/ 以降のパス
    def downloadFileFromS3(self, local_file, s3_file):
        # dir名,ファイル名の取得
        dir_path, file_name = os.path.split(local_file)

        # なければ作る
        if not os.path.exists(dir_path):
            os.makedirs(dir_path)

        # ファイツの保存
        k = Key(self.bucket)
        # 保存するファイル名。s3側
        k.key = s3_file
        # print local_save_path
        # exit()
        #  保存するもの。自分側のファイル
        fout = open(local_file, 'w')
        k.get_file(fout)

    # s3フォルダ内のファイル全部取得
    def downloadFilesFromS3(self, local_dir, s3_dir):
        # なければ作る
        if not os.path.exists(local_dir):
            os.makedirs(local_dir)

        # s3のフォルダ内のファイルのフルパス全取得
        key_name_list = self.getKeyNameList(s3_dir)

        # 1つ1つダウンロードして行く
        for key_name in key_name_list:
            # ファイル名だけ欲しい
            file_name = key_name.split('/')
            file_name = file_name[len(file_name)-1]

            if file_name != '':
                self.downloadFileFromS3(local_dir+file_name, s3_dir+file_name)







    #
